@@ -1,4 +1,4 @@
-# Copyright 2025 BDP Ecosystem Limited. All Rights Reserved.
+# Copyright 2025 BrainX Ecosystem Limited. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@ import brainunit as u
 import numpy as np
 from scipy.spatial.distance import cdist
 
-from braintools.init._init_base import init_call, Initializer
+from braintools.init._init_base import param, Initializer
 from ._base import MultiCompartmentConnectivity, ConnectionResult
 
 __all__ = [
@@ -342,8 +342,8 @@ class CompartmentSpecific(MultiCompartmentConnectivity):
         n_connections = len(pre_indices)
 
         # Generate weights and delays using init_call
-        weights = init_call(self.weight_init, n_connections, rng=self.rng)
-        delays = init_call(self.delay_init, n_connections, rng=self.rng)
+        weights = param(self.weight_init, n_connections, rng=self.rng)
+        delays = param(self.delay_init, n_connections, rng=self.rng)
 
         if delays is not None and not isinstance(delays, u.Quantity):
             delays = np.asarray(delays) * u.ms
@@ -706,8 +706,8 @@ class MorphologyDistance(MultiCompartmentConnectivity):
         post_compartments = np.concatenate(all_post_compartments)
         n_connections = len(pre_indices)
 
-        weights = init_call(self.weight_init, n_connections, rng=self.rng)
-        delays = init_call(self.delay_init, n_connections, rng=self.rng)
+        weights = param(self.weight_init, n_connections, rng=self.rng)
+        delays = param(self.delay_init, n_connections, rng=self.rng)
 
         if delays is not None and not isinstance(delays, u.Quantity):
             delays = np.asarray(delays) * u.ms
@@ -847,8 +847,8 @@ class DendriticTree(MultiCompartmentConnectivity):
         post_compartments = np.concatenate(all_post_compartments)
         n_connections = len(pre_indices)
 
-        weights = init_call(self.weight_init, n_connections, rng=self.rng)
-        delays = init_call(self.delay_init, n_connections, rng=self.rng)
+        weights = param(self.weight_init, n_connections, rng=self.rng)
+        delays = param(self.delay_init, n_connections, rng=self.rng)
 
         if delays is not None and not isinstance(delays, u.Quantity):
             delays = np.asarray(delays) * u.ms
@@ -998,8 +998,8 @@ class AxonalProjection(MultiCompartmentConnectivity):
         pre_compartments = np.full(n_connections, AXON, dtype=np.int64)
         post_compartments = np.full(n_connections, BASAL_DENDRITE, dtype=np.int64)
 
-        weights = init_call(self.weight_init, n_connections, rng=self.rng)
-        delays = init_call(self.delay_init, n_connections, rng=self.rng)
+        weights = param(self.weight_init, n_connections, rng=self.rng)
+        delays = param(self.delay_init, n_connections, rng=self.rng)
 
         if delays is not None and not isinstance(delays, u.Quantity):
             delays = np.asarray(delays) * u.ms
@@ -1224,8 +1224,8 @@ class DendriticIntegration(MultiCompartmentConnectivity):
         post_compartments = np.concatenate(all_post_compartments)
         n_connections = len(pre_indices)
 
-        weights = init_call(self.weight_init, n_connections, rng=self.rng)
-        delays = init_call(self.delay_init, n_connections, rng=self.rng)
+        weights = param(self.weight_init, n_connections, rng=self.rng)
+        delays = param(self.delay_init, n_connections, rng=self.rng)
 
         if delays is not None and not isinstance(delays, u.Quantity):
             delays = np.asarray(delays) * u.ms
@@ -1336,8 +1336,8 @@ class AxonalBranching(MultiCompartmentConnectivity):
             size=n_connections
         ).astype(np.int64)
 
-        weights = init_call(self.weight_init, n_connections, rng=self.rng)
-        delays = init_call(self.delay_init, n_connections, rng=self.rng)
+        weights = param(self.weight_init, n_connections, rng=self.rng)
+        delays = param(self.delay_init, n_connections, rng=self.rng)
 
         if delays is not None and not isinstance(delays, u.Quantity):
             delays = np.asarray(delays) * u.ms
@@ -1452,8 +1452,8 @@ class AxonalArborization(MultiCompartmentConnectivity):
             size=n_connections
         ).astype(np.int64)
 
-        weights = init_call(self.weight_init, n_connections, rng=self.rng)
-        delays = init_call(self.delay_init, n_connections, rng=self.rng)
+        weights = param(self.weight_init, n_connections, rng=self.rng)
+        delays = param(self.delay_init, n_connections, rng=self.rng)
 
         if delays is not None and not isinstance(delays, u.Quantity):
             delays = np.asarray(delays) * u.ms
