@@ -1,4 +1,4 @@
-# Copyright 2025 BDP Ecosystem Limited. All Rights Reserved.
+# Copyright 2025 BrainX Ecosystem Limited. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -35,7 +35,7 @@ import brainunit as u
 import numpy as np
 from scipy.spatial.distance import cdist
 
-from braintools.init._init_base import init_call, Initializer
+from braintools.init._init_base import param, Initializer
 from ._base import PointConnectivity, ConnectionResult
 
 __all__ = [
@@ -191,7 +191,7 @@ class Random(PointConnectivity):
             )
 
         # Generate weights using the initialization class
-        weights = init_call(
+        weights = param(
             self.weight_init,
             n_connections,
             param_type='weight',
@@ -203,7 +203,7 @@ class Random(PointConnectivity):
         )
 
         # Generate delays using the initialization class
-        delays = init_call(
+        delays = param(
             self.delay_init,
             n_connections,
             param_type='delay',
@@ -236,7 +236,7 @@ class Random(PointConnectivity):
 
 # Convenience aliases for common patterns
 class FixedProb(Random):
-    """Alias for Random connectivity with fixed probability."""
+    """Alias for Random connectivity with fixed probability (:class:`Random`)."""
 
     __module__ = 'braintools.conn'
 
@@ -563,7 +563,7 @@ class ClusteredRandom(PointConnectivity):
 
         n_connections = len(pre_indices)
 
-        weights = init_call(
+        weights = param(
             self.weight_init,
             n_connections,
             rng=self.rng,
@@ -573,7 +573,7 @@ class ClusteredRandom(PointConnectivity):
             pre_positions=pre_positions,
             post_positions=post_positions
         )
-        delays = init_call(
+        delays = param(
             self.delay_init,
             n_connections,
             rng=self.rng,
